# Modélisation BUT: exemple de la spécialité Informatique

Le BUT Informatique possède quatre parcours basés sur six compétences. Les
parcours se différencient en BUT3 (S5/S6) par des approfondissements différents
de certaines compétences, comme on le voit ici:

<img src="/screens/but-info-niveaux-parcours.png" width="70%" 
alt="Niveaux de compétences des parcours du BUT Informatique">

Les coefficients des ressources et SAÉs en BUT sont définis localement par les
établissement, ainsi que les crédits ECTS associés aux UE.

Cette page détaille un exemple de mise en place d'un BUT Info.  Cette
configuration est plus complexe que le cas d'une spécialité typique de BUT: on
va supposer que les coefficients d'une même ressource varient suivant le
parcours suivi par l'étudiant, et que les ECTS d'une même UE dépendent parfois
du parcours.

Après mise en place de la formation, nous allons créer les semestres, y inscrire
les étudiants et ternir un jury.

## Saisir ou importer le programme de formation

Avant toute chose, il faut saisir le programme pédagogique de la formation. On
peut souvent l'importer en demandant à des collègues d'autres IUT sur le Discord
assistance ScoDoc, ou à son ACD. le fichier importé sera alors modifié pour
refléter son adaptation locale.

Ensuite, **associer ce programme au référentiel de compétence du BUT Info**:

## Associer la formation à son référentiel de compétences

<img src="/screens/but-info-assoc-refcomp.png" width="50%">

Les référentiels officiels sont fournis par ScoDoc:

<img src="/screens/but-choix-refcomp.png" width="50%">

## Associer les UE à des parcours

Une UE peut intervenir dans un ou plusieurs parcours. Par défaut, elle
intervient dans *tous les parcours*. Un étudiant inscrit à un parcours devra
valider toutes les UEs de celui-ci. Il est donc fondamental de bien indiquer dans
quels parcours intervient une UE.

Pour cela, passer par le formulaire d'édition de l'UE:

<img src="/screens/but-info-edit-ue.png" width="50%">

et cliquer sur le ou les parcours:

<img src="/screens/but-info-choix-ue-parcours.png" width="50%">

Ici l'UE 45, compétence *Conduire*, n'existe que dans les parcours C et D.

Faire de même pour toutes les UEs de la formation qui ne sont pas identiques
dans tous les parcours.

Pour le S4 du BUT Info, cela pourrait donner:

<img src="/screens/but-info-ues-S4.png" width="100%">

où l'on a dupliqué l'UE41 afin de lui affecter des coefficients différents dans
les parcours A et B. Notez que dans cet exemple, l'UE46 est commune et identique
dans tous les parcours.

De même, pour le S6, version simplifiée sans UE spécifiques:

<img src="/screens/but-info-ues-S6.png" width="100%">

## Remarque: nommer les UEs

!!! note "Bien nommer les UEs !"
        Prenez soin de nommer correctement et uniformément vos UEs, c'est
        important pour obtenir de beaux relevés de notes et PV de jurys.

        - pas de redondance: le titre de l'UE ne doit pas reprendre
        l'acronyme, et il est inutile d'indiquer le parcours ou autre infos déjà présentes par ailleurs;
        - acronymes uniformes: `UE41` pour la première UE du S4;
        - le plus simple en BUT est de reprendre le nom (éventuellement abrégé) de la compétence.

        <img src="/screens/but-info-choisir-nom-ue.png" width="50%">

## Associer les UE et les niveaux de compétences

Chaque niveau de compétence (1, 2 ou 3) correspond à une année, donc à deux UEs
consécutives. Il faut indiquer à ScoDoc le niveau de compétence associé à
chacune des UEs.

Pour cela, cliquer sur un parcours:

<img src="/screens/but-info-choix-parcours.png" width="50%">

ce qui permet de visualiser l'ensemble des UEs et compétences du programme:

<img src="/screens/but-info-parcours-formation.png" width="75%">

et d'associer une UE à chaque niveau de compétence:

<img src="/screens/but-info-choix-ue-niveau.png" width="75%">

Le symbole <img src="/screens/but-info-symbole-tc.png" width="20px" alt="TC">
(TC) désigne les niveaux du tronc commun (c'est à dire présents dans tous les
parcours de la spécialité).

Notez qu'une UE ne peut être associée qu'à un seul niveau de compétences (mais
chaque niveau peut-être en relation avec plusieurs UE, de parcours ou programme
différents).

### Parcours A

Après édition, le parcours A ressemble à ceci:

<img src="/screens/but-info-parcours-A.png" width="75%">

Remarques:

- Pas d'UEs en compétences *Administrer*, *Gérer* et *Conduire* car dans ce
  parcours elles s'arrêtent au niveau 2.

- UE5.2 et UE6.2 spécifiques au parcours A car on veut y indiquer des
  coefficients et ECTS spécifiques: nous les avons nommées `UE5.2-A` et
  `UE6.2-A`.

## Parcours B

On fait la même chose pour le parcours B.
Pour changer de parcours, cliquer sur les boutons au dessus:
<img src="/screens/but-info-but-parcours.png" width="30%">

Les niveaux de tronc commun sont déjà associés. Dans certains cas (UE
spécifiques à un parcours, on doit changer l'association). Bien vérifier
l'ensemble avant de poursuivre !

## ECTS par parcours

Dans la plupart des cas, le nombre de crédits ECTS d'une UE est constant. Néanmoins,
certaines spécialités ou établissement, on peut vouloir le faire varier selon le
parcours. Une solution serait de dupliquer l'UE (comme on le fait pour décliner
les coefficients), mais il est plus simple de déclarer les ECTS dans chaque
parcours:

<img src="/screens/but-info-ue-lien-ects.png" width="40%">

<img src="/screens/but-info-ects-parcours.png" width="40%">

## Coefficients des ressources et SAÉs

Imaginons qu'en S4, la ressource `R4.01` ait le coefficient 14 vers l'UE41 dans
le parcours A, mais le coefficient 23 dans le parcours B. Nous avons vu plus
haut que nous avions créé une UE par parcours, `UE41-A` et `UE41-B`. reste à
leur attribuer leurs coefficients via le formulaire habituel:

<img src="/screens/but-info-edit-coefs-S4.png" width="40%">

L'intérêt de cette approche est qu'on a une seule ressource pour les deux
parcours, ce qui simplifie la saisie et le suivi des évaluations et des notes.
Bien sûr, si la ressource était pédagogiquement distincte dans les deux parcours
(activités différentes, examens spécifiques...) il serait préférable de créer
deux versions de la ressources (par exemple `R4.01-A`et `R4.01-B`).

## Mise en place des semestres

La création des semestres ne présentent aucune particularité dans ce cas. Il
faut juste indiquer les parcours proposés dans le semestre. Dans notre exemple:

<img src="/screens/but-info-sem-parcours-A-B.png" width="50%">

Remarque: si la spécialité n'a que des compétences communes dans ce semestre
(tronc commun, fréquent en BUT1), *ne pas cocher de parcours*.

## Affectation des étudiants aux parcours

Nous supposons dans la suite que nous avons les deux parcours A et B dans notre
département, les étudiants des deux parcours étant dans les mêmes semestres
ScoDoc. Les ressources et coefficients proposés sont là pour illustrer et ne
correspondent pas à la réalité.

On affecte les étudiants aux parcours grâce à l'éditeur de groupes et partitions
(accessible via le menu **Groupes**): la partition nommée *parcours* est
spéciale et est utilisée par ScoDoc pour savoir à quel parcours appartient
l'étudiant.

Dans l'exemple ci-dessous, on a deux étudiants dans chaque parcours A et B:

<img src="/screens/but-info-groupes-parcours.png" width="75%">

## Inscriptions des étudiants aux modules de leurs parcours

Il faut que chaque étudiant soit inscrit aux modules (ressources ou SAÉs) de
tronc commun, à et à ceux spécifiques à son parcours. Pour cela, on passe par le
menu "**Inscriptions / Gérer les inscriptions aux UEs et modules**".

Dans chaque module, on peut régler les inscriptions:

<img src="/screens/but-info-inscr-module.png" width="30%">

!!! note "Voir aussi"

    - [Le BUT: détails et calculs](BUT.md)
    - [Guide du responsable de formation](GuideAdminFormation/md)
    - [Programmes de formation](Formations.md)
    - [Référentiel de compétence du BUT](BUTReferentielCompetences.md)
    - [Guide utilisateur](GuideUtilisateur.md)
    - [Tutoriels vidéo](https://www.youtube.com/channel/UCb0JYCBRi0CsE4XFp4ByhXg)
          - [Gestion des UE Bonus](https://www.youtube.com/watch?v=SVbjuDpq-lI)
          - [Mise en place des parcours BUT](https://www.youtube.com/watch?v=OnuOXJo-3ro)
          - [Saisie des codes Apogée](https://www.youtube.com/watch?v=MW0nNhbBjDM)
          - [Du DUT au BUT: comment transformer un programme](https://www.youtube.com/watch?v=9HizGTvYgck)
    - [FAQ](FAQ.md)
    - [Contacts](Contact.md)
