
# Calcul des notes

*Tout ce que vous avez toujours voulu savoir sur le calcul des moyennes...*

Pour les formations par compétences, voir aussi [la page dédiée au BUT](BUT.md).

## En résumé

À chaque instant, ScoDoc prend en compte les notes des évaluations "complètes"
(dans lesquelles toutes les notes ont été saisies ou bien signalées "en attente"
avec le code ATT. Les évaluations partiellement saisies ne sont pas prises en
compte, sauf si l'option "*prise en compte immédiate*" a été cochée sur
l'évaluation.

Les moyennes de modules sont obtenues en calculant dans chacun la moyenne
pondérée des notes disponibles, en utilisant les coefficient des évaluations.

Les moyennes d'UE et générale sont calculées à partir des moyennes de modules,
en utilisant les coefficients du programme pédagogique (dénommé dans ScoDoc
"formation").

Plus de détails ci-dessous.

## Calcul des moyennes de modules

Chaque évaluation produit des notes de différents types:

* note numérique (positive ou nulle): sera normalisée entre 0 et 20

* note absente: considérée comme zéro

* note en attente: non prise en compte

* note excusée: non pris en compte

Chaque étudiant a donc un nombre variable de notes à prendre en compte dans
chaque module. Chaque note est associée à un coefficient: le coefficient de
l'évaluation dans le module.

### En formation classique (hors approches par compétences, BUT)

La moyenne de module est la somme pondérée par le coefficient des évaluations
des notes aux évaluations prises en compte, sauf si on a défini une formule
spécifique.

### En BUT

Comme expliqué en détail sur [la page dédiée au BUT](BUT.md), chaque module
(ressource ou SAÉ) peut produire des notes différentes pour chaque UE. Le
programme pédagogique (adapté du Programme National publié au BO) défini des
coefficients permettant le calcul des moyennes d'UE.

De façon plus fine, chaque évaluation peut s'adresser à un sous-ensemble
d'apprentissages critiques, et donc être associée à une ou plusieurs UE avec des
pondérations différentes: les poids de l'évaluation.

On a donc **pour chaque évaluation**:

- des poids, un par UE, qui sont par défaut égaux à 1 pour les UE concernées
  (c'est à dire ayant un coefficient non nul);
- un coefficient.

Le calcul de la moyenne du module vers les UEs s'effectue en *multipliant* les poids par le coefficient.

## Moyennes d'UE

moyenne_ue = moyenne pondérée des moyennes de modules de l'UE (- malus)

Seuls les modules auxquels l'étudiant est inscrit et dans lesquels il y a des
notes sont considérés.

Le malus appliqué à la moyenne d'UE est donné par la somme des notes du ou des
modules de malus de cette UE (un type spécial de modules, voir
[ModulesMalus](ModulesMalus.md)).

## Calcul de la moyenne générale

### En formations classiques

moyenne = moyenne pondérée des moyennes d'UE + bonus sport/culture

Le coef. d'une UE est par défaut la somme des coefs des modules qui la compose
(et peut donc différer d'un étudiant à un autre, s'ils ne sont pas inscrits aux
mêmes modules).

Toutefois (depuis mai 2020), il est possible de spécifier un coefficient d'UE
dans le programme pédagogique, et de l'utiliser pour calculer la moyenne
générale (option "Utiliser les coefficients d'UE pour calculer la moyenne
générale"). Dans ce cas, les coefficients des modules ne servent qu'à calculer
les moyennes d'UE, qui sont ensuite affectée de leur propre coefficient. De
cette façon, les UE pèsent le même poids pour tous les étudiants, quel que soit
le nombre de modules auquel l'étudiant est inscrit (ce qui peut sembler étrange:
bien réfléchir avant de choisir le mode de calcul adapté à sa formation).

Les modules des UEs de type "Sport & Culture" ne sont évidemment pas pris en
compte dans la moyenne pondérée: ils sont utilisés pour calculer le bonus, comme
expliqué ci-dessous.

### Moyenne générale en BUT

En BUT, on calcule des notes pour les Unités d'Enseignement, et la moyenne
générale n'est pas définie. Toutefois, ScoDoc calcule une *moyenne indicative*,
qui est la moyenne des moyennes des UE du semestre pondérée par leurs ECTS. Voir
détails [sur la page BUT](BUT.md#moyenne-generale)

## Notes de rattrapage

Dans chaque module, il est possible de définir une évaluation de "rattrapage".
Lors de la création (ou modification) de l'évaluation, indiquer le type
"Rattrapage":

![CreateEvaluationRat.png](screens/CreateEvaluationRat.png)

Pour chaque étudiant, la note obtenue à l'évaluation de rattrapage remplace la
moyenne du module, seulement si elle est supérieure à celle-ci.

## Bonus sport/culture

Ce bonus s'applique directement sur la **moyenne générale** et/ou sur les
moyennes d'UE (notamment en BUT).

Les notes des UEs de type spécial "Sport & Culture" sont utilisées pour calculer ce bonus.

Pour qu'un étudiant bénéficie de ce bonus, il doit être inscrit à un module
d'une UE de type "Sport&Culture". Cette UE et modules associés doivent donc être
prévu dans le programme pédagogique.

La règle appliquée dépend de l'établissement. Par exemple, l'Université de
Haute Alsace appliquait le règlement suivant: *Les étudiants de l'IUT peuvent
suivre des enseignements optionnels de l'U.H.A.  (sports, musique, deuxième
langue, culture, etc) non rattachés à une unité d'enseignement. Les points
au-dessus de 10 sur 20 obtenus dans chacune des matières optionnelles sont
cumulés dans la limite de 10 points. 5% de ces points cumulés s'ajoutent à la
moyenne générale du semestre déjà obtenue par l'étudiant.* 

L'administrateur peut changer la fonction de calcul du bonus sport via le
formulaire de configuration accessible (aux admin) depuis la page d'accueil. Si
vous souhaitez disposer d'une nouvelle règle, il faut contacter l'équipe de
développement en indiquant (en français) le règlement en vigueur dans votre
établissement. Le code correspondant sera ajouté via une mise à jour.

## Arrondis et affichages

ScoDoc calcule les notes en haute précision. On peut saisir des notes comme
`12,3456789 / 20` (convenons que c'est un peu ridicule, mais possible).

Les résultats sont en général affichés avec 4 chiffres (12,34/20), soit 1 millième de précision.
Le nombre de chiffres exportés vers Apogée (dans des fichiers textes) est paramétrable.
Les exports vers Excel conservent la précision maximale (types numériques).

Les décisions prises par ScoDoc (`ADM` automatique par exemple) sont calculées
avec une *tolérance* pour éviter que les étudiants ne soient victimes d'erreurs
d'arrondis: par exemple:

```text
Pour valider une RCUE, on vérifie que moy_rcue > sco_codes.BUT_RCUE_SUFFISANT

où est défini comme BUT_RCUE_SUFFISANT = 8.0 - NOTES_TOLERANCE.

avec 
NOTES_TOLERANCE = 0.00499999999999
```

Donc un étudiant avec 7.996 (affichée `08.00` dans les tableaux) validera mais un autre avec 7.995 (affichée `07.99`) ne validera pas.

⚠️ Attention: il y a deux façon d'exporter vers Excel:

1- l'une est fournie par le navigateur (javascript) et part de la version
affichée. C'est commode et conserve la mise en forme du tableau affiché, mais on
n'a pas toute la précision.

2- la seconde est exportée par ScoDoc qui veille à conserver le maximum d'information.

![menu export excel](fig/menu-export-excel.png)


!!! note "Voir aussi"

    - [Guide utilisateur](GuideUtilisateur.md)
    - [Calculs spécifiques en BUT](BUT.md)
    - [FAQ](FAQ.md)
    - [Contacts](Contact.md)
